%define anolis_release 6
Name:           libxml2
Version:        2.11.5
Release:        %{anolis_release}%{?dist}
Summary:        Library providing XML and HTML support

License:        MIT
URL:            http://xmlsoft.org/
Source0:        https://download.gnome.org/sources/%{name}/2.11/%{name}-%{version}.tar.xz
Patch0:         libxml2-multilib.patch
# Patch from openSUSE.
# See:  https://bugzilla.gnome.org/show_bug.cgi?id=789714
Patch1:         libxml2-2.11.1-python3-unicode-errors.patch
Patch2:         fix-CVE-2023-45322.patch

# CVE-2024-34459
# Tracking bug: https://security-tracker.debian.org/tracker/CVE-2024-34459
# Upstream fix: https://gitlab.gnome.org/GNOME/libxml2/-/commit/8ddc7f13337c9fe7c6b6e616f404b0fffb8a5145
Patch3:         Bugfix-for-CVE-2024-34459.patch

# CVE-2024-25062
# Upstream fix: https://gitlab.gnome.org/GNOME/libxml2/-/commit/2b0aac140d739905c7848a42efc60bfe783a39b7
Patch4:         Bugfix-for-CVE-2024-25062.patch

# CVE-2024-40896
# Upstream fix: https://gitlab.gnome.org/GNOME/libxml2/-/commit/ae8f0ac0a2900219c3d762ae0b513e199dcf19a5
Patch5:         1001-fix-CVE-2024-40896.patch

# CVE-2025-32414
# Upstream fix: https://gitlab.gnome.org/GNOME/libxml2/-/commit/8d415b8911be26b12b85497f7cc57143b5321787
Patch6:         bugfix-for-cve-2025-32414.patch

BuildRequires:  cmake-rpm-macros
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(liblzma)

%description
This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select sub nodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.

%package devel
Summary:        Libraries, includes, etc. to develop XML and HTML applications
Requires:       %{name} = %{version}-%{release}
Requires:       zlib-devel
Requires:       xz-devel

%description devel
Libraries, include files, etc you can use to develop XML applications.
This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DtDs, either
at parse time or later once the document has been modified. The output
can be a simple SAX stream or and in-memory DOM like representations.
In this case one can use the built-in XPath and XPointer implementation
to select sub nodes or ranges. A flexible Input/Output mechanism is
available, with existing HTTP and FTP modules and combined to an
URI library.

%package static
Summary:        Static library for libxml2

%description static
Static library for libxml2 provided for specific uses or shaving a few
microseconds when parsing, do not link to them for generic purpose packages.

%package -n python3-%{name}
Summary:        Python 3 bindings for the libxml2 library
BuildRequires:  python3-devel
Requires:       %{name} = %{version}-%{release}
Obsoletes:      %{name}-python3 < %{version}-%{release}
Provides:       %{name}-python3 = %{version}-%{release}

%description -n python3-%{name}
The libxml2-python3 package contains a Python 3 module that permits
applications written in the Python programming language, version 3, to use the
interface supplied by the libxml2 library to manipulate XML files.

This library allows to manipulate XML files. It includes support
to read, modify and write XML and HTML files. There is DTDs support
this includes parsing and validation even with complex DTDs, either
at parse time or later once the document has been modified.

%package doc
Summary:        Doc files for libxml2
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description doc
Doc files for libxml2

%prep
%autosetup -p1
find doc -type f -executable -print -exec chmod 0644 {} ';'

%build
%configure \
    --enable-static \
    --with-legacy \
    --with-ftp \
    --with-xptr-locs \
    --with-python=%{__python3}
%make_build

%install
%make_install

touch -m --reference=%{buildroot}%{_includedir}/libxml2/libxml/parser.h %{buildroot}%{_bindir}/xml2-config

find %{buildroot} -type f -name '*.la' -print -delete
rm -vf %{buildroot}{%{python2_sitearch},%{python3_sitearch}}/*.a
rm -vrf %{buildroot}%{_datadir}/doc/
(cd doc/examples ; make clean ; rm -rf .deps Makefile)
gzip -9 -c doc/libxml2-api.xml > doc/libxml2-api.xml.gz

%generate_compatibility_deps

%check
# Tests require the XML conformance suite, and fail in doc/examples somwhere.
#%make_build runtests

%ldconfig_scriptlets

%files
%dir %{abidir}
%license Copyright
%{_libdir}/libxml2.so.2*
%{abidir}/libxml2.dump
%{_bindir}/xmllint
%{_mandir}/man1/xmllint.1*
%{_bindir}/xmlcatalog
%{_mandir}/man1/xmlcatalog.1*
%{abidir}/xmlcatalog-option.list

%files devel
%doc doc/*.html
%doc doc/tutorial doc/libxml2-api.xml.gz
%doc doc/examples
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/libxml2/
%{_libdir}/libxml2.so
%{_includedir}/libxml2/
%{_bindir}/xml2-config
%{abidir}/xml2-config-option.list
%{_mandir}/man1/xml2-config.1*
%{_datadir}/aclocal/libxml.m4
%{_libdir}/pkgconfig/libxml-2.0.pc
%{_libdir}/cmake/libxml2/

%files static
%license Copyright
%{_libdir}/libxml2.a

%files -n python3-%{name}
%doc python/libxml2class.txt
%doc doc/*.py
%{python3_sitearch}/libxml2mod.so
%{python3_sitelib}/libxml2.py
%{python3_sitelib}/__pycache__/libxml2.*
%{python3_sitelib}/drv_libxml2.py
%{python3_sitelib}/__pycache__/drv_libxml2.*
%{abidir}/libxml2mod.dump

%files doc
%doc NEWS README.md

%changelog
* Mon Apr 14 2025 qizengtian <qizengtian@inspur.com> - 2.11.5-6
- Fix CVE-2025-32414

* Mon Jan 13 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.11.5-5
- to #IBHBVL
- add patch to fix CVE-2024-40896
- Project: TC2024080204
- Signed-off-by: mgb01105731 mgb01105731@alibaba-inc.com

* Mon Aug 12 2024 lidongyue <dongyue@nfschina.com> - 2.11.5-4
- Fix CVE-2024-25062

* Fri Jul 12 2024 lidongyue <dongyue@nfschina.com> - 2.11.5-3
- Fix CVE-2024-34459

* Tue Mar 12 2024 Bo Ren <rb01097748@alibaba-inc.com> - 2.11.5-2
- Rebuild with python3.11

* Wed Aug 16 2023 David King <amigadave@amigadave.com> - 2.11.5-1
- Update to 2.11.5 and fix CVE-2023-45322

* Fri Apr 14 2023 Funda Wang <fundawang@yeah.net> - 2.10.4-1
- New version 2.10.4

* Fri Nov 25 2022 Funda Wang <fundawang@yeah.net> - 2.10.3-1
- New version 2.10.3

* Wed Oct 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.9.14-2
- optimise spec file

* Tue Aug 30 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.9.14-1
- update to 2.9.14

* Tue Mar  8 2022 forrest_ly <flin@linux.alibaba.com> - 2.9.13-1 
- Init for Anolis OS 23
